// Load data from CSV file asynchronously
d3.csv(
  'https://raw.githubusercontent.com/sriharsha729/assignment2CSVdata1/main/data-1%20(3).csv',
)
  .then(function (data) {
    // Convert 'above 8.5' to a number and log the data
    data.forEach(function (d) {
      d['above 8.5'] = +d['above 8.5']; // make sure the value is a number
    });

    // Set the dimensions and margins of the graph
    var width = 850, // increased width to make room for legend
      height = 470,
      margin = 40;

    // The radius of the pie chart is half the smallest side
    var radius = Math.min(width, height) / 2 - margin;

    // Append the svg object to the div called 'chart'
    var svg = d3
      .select('#chart')
      .append('svg')
      .attr('width', width)
      .attr('height', height);

    // Group for the pie chart
    var pieGroup = svg
      .append('g')
      .attr(
        'transform',
        `translate(${radius + margin}, ${height / 2})`,
      );

    // Set the color scale
    var color = d3
      .scaleOrdinal()
      .domain(
        data.map(function (d) {
          return d.genre;
        }),
      )
      .range(d3.schemeCategory10);

    // Compute the position of each group on the pie
    var pie = d3.pie().value(function (d) {
      return d['above 8.5'];
    });

    // Shape helper to build arcs
    var arcGenerator = d3
      .arc()
      .innerRadius(0)
      .outerRadius(radius);

    // Build the pie chart
    pieGroup
      .selectAll('mySlices')
      .data(pie(data))
      .enter()
      .append('path')
      .attr('d', arcGenerator)
      .attr('fill', function (d) {
        return color(d.data.genre);
      })
      .attr('stroke', 'black')
      .style('stroke-width', '2px')
      .style('opacity', 0.7);

    // Define a legend group with a little bit of translation to the right
    var legend = svg
      .append('g')
      .attr(
        'transform',
        `translate(${2 * radius + margin}, ${margin})`,
      );

    // Define legend size and spacing
    var legendRectSize = 20;
    var legendSpacing = 5;

    // Add legend entries
    var legendItem = legend
      .selectAll('.legend')
      .data(color.domain())
      .enter()
      .append('g')
      .attr('class', 'legend')
      .attr('transform', function (d, i) {
        return `translate(0, ${i * (legendRectSize + legendSpacing)})`;
      });

    // Add colored squares to legend
    legendItem
      .append('rect')
      .attr('width', legendRectSize)
      .attr('height', legendRectSize)
      .style('fill', color)
      .style('stroke', color);

    // Add text to legend
    legendItem
      .append('text')
      .attr('x', legendRectSize + legendSpacing)
      .attr('y', legendRectSize - legendSpacing)
      .text(function (d) {
        return d;
      })
      .attr('text-anchor', 'start')
      .style('alignment-baseline', 'middle');
  })
  .catch(function (error) {
    console.log('Error loading the data: ', error);
  });
